==> piwigo-16.0.0.zip: piwigo/themes/modus/language/ko_KR/theme.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2017 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Display page banner'] = '페이지 배너 표시';
$lang['Explore'] = '탐색하기';
$lang['Modus theme config'] = 'Modus 테마 설정';
$lang['modus_theme'] = 'modus_theme';
$lang['%d album'] = '%d 앨범';
$lang['%d albums'] = '%d 앨범';
$lang['%d pixels'] = '%d 픽셀';
$lang['Album thumbnails'] = '앨범 썸네일';
$lang['Default size for thumbnails'] = '썸네일 기본 크기';
$lang['Default size for thumbnails on high density display (retina)'] = '썸네일 기본 크기 (레티나, 고화질 디스플레이)';
$lang['Default sizes'] = '기본 크기';
$lang['Skin'] = '스킨';
$lang['Use square thumbs'] = '직사각형 썸네일 사용하기';

==> piwigo-16.3.0.zip: piwigo/themes/modus/language/ko_KR/theme.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2017 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Display page banner'] = '페이지 배너 표시';
$lang['Explore'] = '탐색하기';
$lang['Modus theme config'] = 'Modus 테마 설정';
$lang['modus_theme'] = 'modus_theme';
$lang['%d album'] = '%d개의 앨범';
$lang['%d albums'] = '%d개의 앨범';
$lang['%d pixels'] = '%d픽셀';
$lang['Album thumbnails'] = '앨범 썸네일';
$lang['Default size for thumbnails'] = '썸네일 기본 크기';
$lang['Default size for thumbnails on high density display (retina)'] = '썸네일 기본 크기 (레티나, 고화질 디스플레이)';
$lang['Default sizes'] = '기본 크기';
$lang['Skin'] = '스킨';
$lang['Use square thumbs'] = '정사각형 썸네일 사용';
$lang['Admin'] = '관리자';
